import FlippableCard from "./FlippableCard";
import {nextButton, skipToTest, symptoms, symptomsCards, toTest} from "../../public/lit/texts";
import {languageAtom} from "../atoms/languageAtom";
import {useRecoilValue} from "recoil";
import {Texts, useAnimate} from "../hooks/useAnimate";
import {useRef} from "react";
import Typewriter, {TypewriterClass} from "typewriter-effect";
import {useTranslate} from "../hooks/useTranslate";
import {useNavigate} from "react-router-dom";

const Symptoms = () => {
    const language = useRecoilValue(languageAtom);
    const typewriterRef = useRef<TypewriterClass>();
    const nextButtonText = useTranslate(nextButton);
    const testText = useTranslate(toTest);
    const skipButtonText = useTranslate(skipToTest);
    const navigate = useNavigate();
    const {onInit, handleClick, isAnimationComplete, isLast, currentIndex} = useAnimate({
        typewriterRef,
        link: '/',
        text: symptoms,
        audioFiles: []
    });
    return (
        <div className="flex h-screen">
            <div id="intro-text" className="w-2/6 p-4 font-speech">
                <Typewriter
                    options={{
                        delay: 40,
                    }}
                    onInit={(typewriter) => onInit({typewriter, pauseFor: 0})}
                />
            <div className="mt-20 flex justify-evenly">
                <button
                    onClick={handleClick}
                    className={`mt-20 border-4 border-black font-primary ${
                        !isAnimationComplete ? 'bg-gray-main' : 'bg-yellow-main'
                    }`}
                >
                    {isLast ? testText : nextButtonText}
                </button>
                {!isLast && (
                    <button
                        onClick={() => navigate("/insulin")}
                        className={`mt-20 border-4 border-black font-primary bg-yellow-main`}
                    >
                        {skipButtonText}
                    </button>
                )}
            </div>
            </div>

            <div className="w-4/6 p-4">
                <div className="grid grid-rows-2 grid-cols-4 gap-4">
                    {symptomsCards.map((card, index) => (
                        <div
                            key={card.id}
                            className={`${
                                index < currentIndex - 2 ? "opacity-100" : "opacity-0"
                            } transition-opacity duration-1000`}
                        >
                            <FlippableCard
                                key={card.id}
                                image={card.image}
                                text={card.text[language as keyof Texts]}
                                alt={card.id}
                            />
                        </div>
                    ))}
                </div>
            </div>
        </div>
    );
}
export default Symptoms;
